//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by electric.rc
//
#define IDD_ABOUTBOX                    100
#define IDD_ELECTRIC_DIALOG             101
#define IDR_MAINFRAME                   128
#define IDR_ELECTRTYPE                  129
#define IDC_CURSORPEN                   130
#define IDC_CURSORTECH                  131
#define IDC_CURSORHAND                  132
#define IDD_DIALOG1                     132
#define IDC_CURSORMENU                  133
#define IDC_CURSORTTY                   135
#define IDD_DIALOG2                     136
#define IDD_DIALOG3                     137
#define IDD_DIALOG4                     139
#define IDB_BITMAP1                     140
#define IDB_BITMAP2                     142
#define ID_ELECTRIC_MENU01              32772
#define ID_ELECTRIC_MENU02              32773
#define ID_ELECTRIC_MENU03              32774
#define ID_ELECTRIC_MENU04              32775
#define ID_ELECTRIC_MENU05              32776
#define ID_ELECTRIC_MENU06              32777
#define ID_ELECTRIC_MENU07              32778
#define ID_ELECTRIC_MENU08              32779
#define ID_ELECTRIC_MENU09              32780
#define ID_ELECTRIC_MENU10              32781
#define ID_ELECTRIC_MENU11              32782
#define ID_ELECTRIC_MENU12              32783
#define ID_ELECTRIC_MENU13              32784
#define ID_ELECTRIC_MENU14              32785
#define ID_ELECTRIC_MENU15              32786
#define ID_ELECTRIC_MENU16              32787
#define ID_ELECTRIC_MENU17              32788
#define ID_ELECTRIC_MENU18              32789
#define ID_ELECTRIC_MENU19              32790
#define ID_ELECTRIC_MENU20              32791
#define ID_ELECTRIC_MENU21              32792
#define ID_ELECTRIC_MENU22              32793
#define ID_ELECTRIC_MENU23              32794
#define ID_ELECTRIC_MENU24              32795
#define ID_ELECTRIC_MENU25              32796
#define ID_ELECTRIC_MENU26              32797
#define ID_ELECTRIC_MENU27              32798
#define ID_ELECTRIC_MENU28              32799
#define ID_ELECTRIC_MENU29              32800
#define ID_ACCELERATOR_EX               32801
#define ID_ACCELERATOR_A                40000
#define ID_ACCELERATOR_B                40001
#define ID_ACCELERATOR_C                40002
#define ID_ACCELERATOR_D                40003
#define ID_ACCELERATOR_E                40004
#define ID_ACCELERATOR_F                40005
#define ID_ACCELERATOR_G                40006
#define ID_ACCELERATOR_H                40007
#define ID_ACCELERATOR_I                40008
#define ID_ACCELERATOR_J                40009
#define ID_ACCELERATOR_K                40010
#define ID_ACCELERATOR_L                40011
#define ID_ACCELERATOR_M                40012
#define ID_ACCELERATOR_N                40013
#define ID_ACCELERATOR_O                40014
#define ID_ACCELERATOR_P                40015
#define ID_ACCELERATOR_Q                40016
#define ID_ACCELERATOR_R                40017
#define ID_ACCELERATOR_S                40018
#define ID_ACCELERATOR_T                40019
#define ID_ACCELERATOR_U                40020
#define ID_ACCELERATOR_V                40021
#define ID_ACCELERATOR_W                40022
#define ID_ACCELERATOR_X                40023
#define ID_ACCELERATOR_Y                40024
#define ID_ACCELERATOR_Z                40025
#define ID_ACCELERATOR_0                40026
#define ID_ACCELERATOR_1                40027
#define ID_ACCELERATOR_2                40028
#define ID_ACCELERATOR_3                40029
#define ID_ACCELERATOR_4                40030
#define ID_ACCELERATOR_5                40031
#define ID_ACCELERATOR_6                40032
#define ID_ACCELERATOR_7                40033
#define ID_ACCELERATOR_8                40034
#define ID_ACCELERATOR_9                40035
#define ID_DIALOGITEM_0                 45000
#define ID_DIALOGITEM_1                 45001
#define ID_DIALOGITEM_2                 45002
#define ID_DIALOGITEM_3                 45003
#define ID_DIALOGITEM_4                 45004
#define ID_DIALOGITEM_5                 45005
#define ID_DIALOGITEM_6                 45006
#define ID_DIALOGITEM_7                 45007
#define ID_DIALOGITEM_8                 45008
#define ID_DIALOGITEM_9                 45009
#define ID_DIALOGITEM_10                45010
#define ID_DIALOGITEM_11                45011
#define ID_DIALOGITEM_12                45012
#define ID_DIALOGITEM_13                45013
#define ID_DIALOGITEM_14                45014
#define ID_DIALOGITEM_15                45015
#define ID_DIALOGITEM_16                45016
#define ID_DIALOGITEM_17                45017
#define ID_DIALOGITEM_18                45018
#define ID_DIALOGITEM_19                45019
#define ID_DIALOGITEM_20                45020
#define ID_DIALOGITEM_21                45021
#define ID_DIALOGITEM_22                45022
#define ID_DIALOGITEM_23                45023
#define ID_DIALOGITEM_24                45024
#define ID_DIALOGITEM_25                45025
#define ID_DIALOGITEM_26                45026
#define ID_DIALOGITEM_27                45027
#define ID_DIALOGITEM_28                45028
#define ID_DIALOGITEM_29                45029
#define ID_DIALOGITEM_30                45030
#define ID_DIALOGITEM_31                45031
#define ID_DIALOGITEM_32                45032
#define ID_DIALOGITEM_33                45033
#define ID_DIALOGITEM_34                45034
#define ID_DIALOGITEM_35                45035
#define ID_DIALOGITEM_36                45036
#define ID_DIALOGITEM_37                45037
#define ID_DIALOGITEM_38                45038
#define ID_DIALOGITEM_39                45039
#define ID_DIALOGITEM_40                45040
#define ID_DIALOGITEM_41                45041
#define ID_DIALOGITEM_42                45042
#define ID_DIALOGITEM_43                45043
#define ID_DIALOGITEM_44                45044
#define ID_DIALOGITEM_45                45045
#define ID_DIALOGITEM_46                45046
#define ID_DIALOGITEM_47                45047
#define ID_DIALOGITEM_48                45048
#define ID_DIALOGITEM_49                45049
#define ID_DIALOGITEM_50                45050
#define ID_DIALOGITEM_51                45051
#define ID_DIALOGITEM_52                45052
#define ID_DIALOGITEM_53                45053
#define ID_DIALOGITEM_54                45054
#define ID_DIALOGITEM_55                45055
#define ID_DIALOGITEM_56                45056
#define ID_DIALOGITEM_57                45057
#define ID_DIALOGITEM_58                45058
#define ID_DIALOGITEM_59                45059
#define ID_DIALOGITEM_60                45060
#define ID_INDICATOR_ELECTRIC01         59142
#define ID_INDICATOR_ELECTRIC02         59143
#define ID_INDICATOR_ELECTRIC03         59144
#define ID_INDICATOR_ELECTRIC04         59145
#define ID_INDICATOR_ELECTRIC05         59146
#define ID_INDICATOR_ELECTRIC06         59147
#define ID_INDICATOR_ELECTRIC07         59148
#define ID_INDICATOR_ELECTRIC08         59149
#define ID_INDICATOR_ELECTRIC09         59150
#define ID_INDICATOR_ELECTRIC10         59151
#define ID_INDICATOR_ELECTRIC11         59152
#define ID_INDICATOR_ELECTRIC12         59153
#define ID_INDICATOR_ELECTRIC13         59154
#define ID_INDICATOR_ELECTRIC14         59155
#define ID_INDICATOR_ELECTRIC15         59156
#define ID_INDICATOR_ELECTRIC16         59157
#define ID_INDICATOR_ELECTRIC17         59158

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        143
#define _APS_NEXT_COMMAND_VALUE         32802
#define _APS_NEXT_CONTROL_VALUE         1000
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
